/**
 * @license Copyright 2017 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */
'use strict';

const groupIdToName = {
  loading: 'Network request loading',
  parseHTML: 'Parsing HTML & CSS',
  styleLayout: 'Style & Layout',
  compositing: 'Compositing',
  painting: 'Paint',
  gpu: 'GPU',
  scripting: 'Script Evaluation',
  scriptParseCompile: 'Script Parsing & Compile',
  scriptGC: 'Garbage collection',
  other: 'Other',
  images: 'Images',
};

const taskToGroup = {
  'Animation': groupIdToName.painting,
  'Async Task': groupIdToName.other,
  'Frame Start': groupIdToName.painting,
  'Frame Start (main thread)': groupIdToName.painting,
  'Cancel Animation Frame': groupIdToName.scripting,
  'Cancel Idle Callback': groupIdToName.scripting,
  'Compile Script': groupIdToName.scriptParseCompile,
  'Composite Layers': groupIdToName.compositing,
  'Console Time': groupIdToName.scripting,
  'Image Decode': groupIdToName.images,
  'Draw Frame': groupIdToName.painting,
  'Embedder Callback': groupIdToName.scripting,
  'Evaluate Script': groupIdToName.scripting,
  'Event': groupIdToName.scripting,
  'Animation Frame Fired': groupIdToName.scripting,
  'Fire Idle Callback': groupIdToName.scripting,
  'Function Call': groupIdToName.scripting,
  'DOM GC': groupIdToName.scriptGC,
  'GC Event': groupIdToName.scriptGC,
  'GPU': groupIdToName.gpu,
  'Hit Test': groupIdToName.compositing,
  'Invalidate Layout': groupIdToName.styleLayout,
  'JS Frame': groupIdToName.scripting,
  'Input Latency': groupIdToName.scripting,
  'Layout': groupIdToName.styleLayout,
  'Major GC': groupIdToName.scriptGC,
  'DOMContentLoaded event': groupIdToName.scripting,
  'First paint': groupIdToName.painting,
  'FMP': groupIdToName.painting,
  'FMP candidate': groupIdToName.painting,
  'Load event': groupIdToName.scripting,
  'Minor GC': groupIdToName.scriptGC,
  'Paint': groupIdToName.painting,
  'Paint Image': groupIdToName.images,
  'Paint Setup': groupIdToName.painting,
  'Parse Stylesheet': groupIdToName.parseHTML,
  'Parse HTML': groupIdToName.parseHTML,
  'Parse Script': groupIdToName.scriptParseCompile,
  'Other': groupIdToName.other,
  'Rasterize Paint': groupIdToName.painting,
  'Recalculate Style': groupIdToName.styleLayout,
  'Request Animation Frame': groupIdToName.scripting,
  'Request Idle Callback': groupIdToName.scripting,
  'Request Main Thread Frame': groupIdToName.painting,
  'Image Resize': groupIdToName.images,
  'Finish Loading': groupIdToName.loading,
  'Receive Data': groupIdToName.loading,
  'Receive Response': groupIdToName.loading,
  'Send Request': groupIdToName.loading,
  'Run Microtasks': groupIdToName.scripting,
  'Schedule Style Recalculation': groupIdToName.styleLayout,
  'Scroll': groupIdToName.compositing,
  'Task': groupIdToName.other,
  'Timer Fired': groupIdToName.scripting,
  'Install Timer': groupIdToName.scripting,
  'Remove Timer': groupIdToName.scripting,
  'Timestamp': groupIdToName.scripting,
  'Update Layer': groupIdToName.compositing,
  'Update Layer Tree': groupIdToName.compositing,
  'User Timing': groupIdToName.scripting,
  'Create WebSocket': groupIdToName.scripting,
  'Destroy WebSocket': groupIdToName.scripting,
  'Receive WebSocket Handshake': groupIdToName.scripting,
  'Send WebSocket Handshake': groupIdToName.scripting,
  'XHR Load': groupIdToName.scripting,
  'XHR Ready State Change': groupIdToName.scripting,
};

module.exports = {
  groupIdToName,
  taskToGroup,
};
